@@ -13,7 +13,7 @@
    @author Robin Gareus <robin@gareus.org>
    @copyright
 
-   Copyright (C) 2006-2012 Robin Gareus <robin@gareus.org>
+   Copyright (C) 2006-2014 Robin Gareus <robin@gareus.org>
 
    Copyright (C) 2008-2009 Jan Weiß <jan@geheimwerk.de>
 
@@ -40,32 +40,39 @@
 extern "C" {
 #endif
 
+#if defined _WIN32 && !defined(__LITTLE_ENDIAN__)
+#define __LITTLE_ENDIAN__
+#endif
+
 #ifdef __BIG_ENDIAN__
 # define LTC_BIG_ENDIAN
 #elif defined _BIG_ENDIAN
 # define LTC_BIG_ENDIAN
-#else
-# include <endian.h>
+#elif defined __BYTE_ORDER__
 # if __BYTE_ORDER__ ==  __ORDER_BIG_ENDIAN__
 #  define LTC_BIG_ENDIAN
 # endif
+#elif !defined __LITTLE_ENDIAN__
+# include <endian.h> // machine/endian.h
+# if (defined __BYTE_ORDER__ && defined __ORDER_BIG_ENDIAN__ && __BYTE_ORDER__ ==  __ORDER_BIG_ENDIAN__)
+#  define LTC_BIG_ENDIAN
+# endif
 #endif
 
-
 #include <stddef.h> /* size_t */
 
 #ifndef DOXYGEN_IGNORE
 /* libltc version */
-#define LIBLTC_VERSION "1.1.3"
+#define LIBLTC_VERSION "1.2.0"
 #define LIBLTC_VERSION_MAJOR  1
-#define LIBLTC_VERSION_MINOR  1
-#define LIBLTC_VERSION_MICRO  3
+#define LIBLTC_VERSION_MINOR  2
+#define LIBLTC_VERSION_MICRO  0
 
 /* interface revision number
  * http://www.gnu.org/software/libtool/manual/html_node/Updating-version-info.html
  */
 #define LIBLTC_CUR 11
-#define LIBLTC_REV  2
+#define LIBLTC_REV  4
 #define LIBLTC_AGE  0
 #endif /* end DOXYGEN_IGNORE */
 
